@@ -32,7 +32,7 @@ private:
 	static FonbookManager* me;
 	Fonbooks fonbooks;
 	FonbookManager(bool saveOnShutdown);
-	Fonbook *GetActiveFonbook() const;
+	Fonbook *getActiveFonbook() const;
 	size_t activeFonbookPos;
 	bool saveOnShutdown;
 public:
@@ -69,108 +69,108 @@ public:
 	 * Switch to next displayable phonebook.
 	 * @return void
 	 */
-	void NextFonbook();
+	void nextFonbook();
 	/**
 	 * Resolves the number given to the corresponding name.
 	 * @param number to resolve
 	 * @return resolved name and type or the number, if unsuccessful
 	 */
-	virtual sResolveResult ResolveToName(std::string number);
+	sResolveResult resolveToName(std::string number) override;
 	/**
 	 * Returns a specific telephonebook entry.
 	 * @param id unique identifier of the requested entry
-	 * @return the entry with key id or NULL, if unsuccessful
+	 * @return the entry with key id or nullptr, if unsuccessful
 	 */
-	const FonbookEntry *RetrieveFonbookEntry(size_t id) const;
+	const FonbookEntry *retrieveFonbookEntry(size_t id) const override;
 	/**
 	 * Changes the Fonbook entry with the given id
 	 * @param id unique identifier to the entry to be changed
 	 * @param fe FonbookEntry with the new content
 	 * @return true, if successful
 	 */
-	virtual bool ChangeFonbookEntry(size_t id, FonbookEntry &fe);
+	bool changeFonbookEntry(size_t id, FonbookEntry &fe) override;
 	/**
 	 * Sets the default number for a Fonbook entry with the given id
 	 * @param id unique identifier to the entry to be changed
 	 * @param type the new default
 	 * @return true, if successful
 	 */
-	virtual bool SetDefault(size_t id, size_t pos);
+	virtual bool setDefault(size_t id, size_t pos);
 	/**
 	 * Adds a new entry to the phonebook.
 	 * @param fe a new phonebook entry
 	 * @return true, if add was successful
 	 */
-	virtual void AddFonbookEntry(FonbookEntry &fe, size_t position = std::string::npos);
+	void addFonbookEntry(FonbookEntry &fe, size_t position = std::string::npos) override;
 	/**
 	 * Adds a new entry to the phonebook.
 	 * @param id unique id to the entry to be deleted
 	 * @return true, if deletion was successful
 	 */
-	virtual bool DeleteFonbookEntry(size_t id);
+	bool deleteFonbookEntry(size_t id) override;
 	/**
 	 * Clears all entries from phonebook.
 	 */
-	virtual void Clear();
+	void clear() override;
 	/**
 	 * Save pending changes.
 	 * Can be called periodically to assert pending changes in a phone book are written.
 	 */
-	void Save();
+	void save() override;
 	/**
 	 * Returns if it is possible to display the entries of this phonebook.
 	 * @return true, if this phonebook has displayable entries. "Reverse lookup only" phonebooks must return false here.
 	 */
-	virtual bool isDisplayable() const;
+	bool isDisplayable() const override;
 	/**
 	 * Returns if this phonebook is ready to use.
 	 * @return true, if this phonebook is ready to use
 	 */
-	virtual bool isInitialized() const;
+	bool isInitialized() const override;
 	/**
 	 * Returns if this phonebook is writeable, e.g. entries can be added or modified.
 	 * @return true, if this phonebook is writeable
 	 */
-	virtual bool isWriteable() const;
+	bool isWriteable() const override;
 	/**
 	 * Returns if this phonebook has changes that are not yet written.
 	 * @return true, if changes are pending
 	 */
-	virtual bool isModified() const;
+	bool isModified() const override;
 	/**
 	 * Sets the initialized-status.
 	 * @param isInititalized the value initialized is set to
 	 */
-	virtual void setInitialized(bool isInitialized);
+	void setInitialized(bool isInitialized) override;
 	/**
 	 * Sorts the phonebook's entries by the given element and in given order.
 	 * @param the element used for sorting
 	 * @param true if sort order is ascending, false otherwise
 	 */
-	virtual void Sort(FonbookEntry::eElements element = FonbookEntry::ELEM_NAME, bool ascending = true);
+	void sort(FonbookEntry::eElements element = FonbookEntry::ELEM_NAME, bool ascending = true) override;
 	/**
 	 *  Returns the number of entries in the telephonebook.
 	 * @return the number of entries or cFonbook::npos, if requesting specific telephonebook entries is not possible for this telephonebook
 	 */
-	size_t GetFonbookSize() const;
+	size_t getFonbookSize() const override;
 	/**
 	 *  Reloads the telephonebook's content
 	 */
-	void Reload();
+	void reload() override;
 	/**
 	 *  Returns a string that should be displayed as title in the menu when the telephonebook is displayed.
 	 */
-	std::string GetTitle() const;
+	std::string getTitle() const override;
 	/**
 	 * Returns the technical id of this phonebook. This id has to be unique among all phonebooks and is used when storing
 	 * the plugin's setup.
 	 * @return the technical id
 	 */
-	virtual std::string GetTechId() const;
+	virtual std::string getTechId() const override;
 	/**
 	 *
 	 */
-	Fonbooks *GetFonbooks();
+	Fonbooks *getFonbooks();
 };
 
 }
