@@ -1,7 +1,7 @@
 /*
  * libfritz++
  *
- * Copyright (C) 2007-2010 Joachim Wilke <libfritz@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <libfritz@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,12 +19,9 @@
  *
  */
 
+#ifndef FONBOOKS_H
+#define FONBOOKS_H
 
-#ifndef FONBOOKS_H_
-#define FONBOOKS_H_
-
-#include <string>
-#include <vector>
 #include "Fonbook.h"
 
 namespace fritz{
