@@ -22,23 +22,25 @@
 #ifndef FRITZFONBOOK_H
 #define FRITZFONBOOK_H
 
-#include <cc++/thread.h>
+#include <string>
+#include <thread>
 
 #include "XmlFonbook.h"
 
 namespace fritz{
 
-class FritzFonbook : public ost::Thread, public XmlFonbook {
+class FritzFonbook : public XmlFonbook {
 			friend class FonbookManager;
 private:
+	std::thread *thread;
 	FritzFonbook();
-	void ParseHtmlFonbook(std::string *msg);
-	virtual void Write();
+	void parseHtmlFonbook(std::string *msg);
+	void write() override;
 public:
 	virtual ~FritzFonbook();
-	bool Initialize();
+	bool initialize() override;
 	void run();
-	void Reload();
+	void reload() override;
 };
 
 }
