@@ -1,7 +1,7 @@
 /*
  * libfritz++
  *
- * Copyright (C) 2007-2010 Joachim Wilke <libfritz@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <libfritz@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,8 +19,8 @@
  *
  */
 
-#ifndef LOCALFONBOOK_H_
-#define LOCALFONBOOK_H_
+#ifndef LOCALFONBOOK_H
+#define LOCALFONBOOK_H
 
 #include "XmlFonbook.h"
 
@@ -31,11 +31,11 @@ class LocalFonbook : public XmlFonbook {
 private:
 	char* filePath;
 	LocalFonbook();
-	void ParseCsvFonbook(std::string filePath);
-	virtual void Write();
+	void parseCsvFonbook(std::string filePath);
+	void write() override;
 public:
-	bool Initialize();
-	void Reload();
+	bool initialize() override;
+	void reload() override;
 };
 
 }
