@@ -1,7 +1,7 @@
 /*
  * libfritz++
  *
- * Copyright (C) 2007-2010 Joachim Wilke <libfritz@joachim-wilke.de>
+ * Copyright (C) 2007-2012 Joachim Wilke <libfritz@joachim-wilke.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,35 +19,23 @@
  *
  */
 
+#include "OertlichesFonbook.h"
 
 #include <unistd.h>
-#include "OertlichesFonbook.h"
+
 #include "Config.h"
-#include "HttpClient.h"
+#include <libnet++/HttpClient.h>
 #include "Tools.h"
+#include <liblog++/Log.h>
 
 namespace fritz{
 
 OertlichesFonbook::OertlichesFonbook()
-{
-	title = I18N_NOOP("das-oertliche.de");
-	techId = "OERT";
-	displayable = false;
-}
+:LookupFonbook(I18N_NOOP("das-oertliche.de"), "OERT")
+{}
 
-OertlichesFonbook::~OertlichesFonbook()
-{
-}
-
-bool OertlichesFonbook::Initialize() {
-	setInitialized(true);
-	return true;
-}
-
-Fonbook::sResolveResult OertlichesFonbook::ResolveToName(std::string number) const {
-	Fonbook::sResolveResult result;
-	result.name = number;
-	result.type = FonbookEntry::TYPE_NONE;
+Fonbook::sResolveResult OertlichesFonbook::lookup(std::string number) const {
+	Fonbook::sResolveResult result(number);
 
 	// resolve only (german) phone numbers
 	if (number.length() == 0 || Tools::NormalizeNumber(number).find("0049") != 0)
@@ -57,12 +45,14 @@ Fonbook::sResolveResult OertlichesFonbook::ResolveToName(std::string number) con
 	std::string name;
 	try {
 		DBG("sending reverse lookup request for " << (gConfig->logPersonalInfo()? Tools::NormalizeNumber(number) : HIDDEN) << " to www.dasoertliche.de");
-		std::string host = "www.dasoertliche.de";
-		HttpClient tc(host);
-		msg = tc.Get(std::stringstream().flush()
-		   << "/Controller?form_name=search_inv&ph=" << Tools::NormalizeNumber(number));
-	} catch (ost::SockException &se) {
-		ERR("Exception - " << se.what());
+		network::HttpClient::param_t params = {
+				{ "form_name", "search_inv"},
+				{ "ph", Tools::NormalizeNumber(number)},
+		};
+		network::HttpClient tc("www.dasoertliche.de");
+		msg = tc.get("/Controller", params);
+	} catch (std::runtime_error &re) {
+		ERR("Exception - " << re.what());
 		return result;
 	}
 	// check that at most one result is returned
@@ -84,13 +74,9 @@ Fonbook::sResolveResult OertlichesFonbook::ResolveToName(std::string number) con
 	std::string dataset = msg.substr(start, stop - start);
 	name = Tools::Tokenize(dataset, ',', 5);
 	name = name.substr(2, name.length()-3);
-	// convert the string from latin1 to current system character table
-	CharSetConv *conv = new CharSetConv("ISO-8859-1", CharSetConv::SystemCharacterTable());
-	const char *s_converted = conv->Convert(name.c_str());
-	name = s_converted;
-	delete (conv);
 	INF("resolves to " << (gConfig->logPersonalInfo() ? name.c_str() : HIDDEN));
 	result.name = name;
+	result.successful = true;
 	return result;
 }
 
