@@ -25,8 +25,11 @@
 #include <unistd.h>
 
 #include "Config.h"
-#include "HttpClient.h"
+#include <libnet++/HttpClient.h>
 #include "Tools.h"
+#include <liblog++/Log.h>
+#include <libconv++/EntityConverter.h>
+#include <boost/regex.hpp>
 
 namespace fritz{
 
@@ -34,7 +37,7 @@ TelLocalChFonbook::TelLocalChFonbook()
 : LookupFonbook(I18N_NOOP("tel.local.ch"), "LOCCH")
 {}
 
-TelLocalChFonbook::sResolveResult TelLocalChFonbook::Lookup(std::string number) const {
+TelLocalChFonbook::sResolveResult TelLocalChFonbook::lookup(std::string number) const {
 	TelLocalChFonbook::sResolveResult result(number);
 
 	// resolve only (swiss) phone numbers
@@ -45,39 +48,27 @@ TelLocalChFonbook::sResolveResult TelLocalChFonbook::Lookup(std::string number)
 	std::string name;
 	try {
 		DBG("sending reverse lookup request for " << Tools::NormalizeNumber(number) << " to tel.local.ch");
-		std::string host = "tel.local.ch";
-		HttpClient tc(host);
-		msg = tc.Get(std::stringstream().flush()
-		   << "/de/q/" <<  Tools::NormalizeNumber(number)
-		   << ".html");
-	} catch (ost::SockException &se) {
+		network::HttpClient tc("mobile.tel.local.ch");
+		std::stringstream ss;
+		ss << "/de/q/" <<  Tools::NormalizeNumber(number) << ".html";
+		msg = tc.get(ss.str());
+	} catch (std::runtime_error &se) {
 		ERR("Exception - " << se.what());
 		return result;
 	}
 	// parse answer
-	size_t start = msg.find("<h2 class");
+	boost::regex expression("<h2 class[^>]+><a [^>]+>(.+)</a></h2>");
+	boost::smatch what;
+	if (boost::regex_search(msg, what, expression)) {
+		name = what[1];
+		name = convert::EntityConverter::DecodeEntities(name);
 
-	if (start == std::string::npos) {
+		INF("resolves to " << name.c_str());
+		result.name = name;
+		result.successful = true;
+	} else
 		INF("no entry found.");
-		return result;
-	}
-	// add the length of search pattern
-	start += 15;
-
-	size_t stop  = msg.find("</h2>", start);
-	name = msg.substr(start, stop - start);
 	
-	// convert the string from latin1 to current system character table
-	CharSetConv *conv = new CharSetConv("UTF-8", CharSetConv::SystemCharacterTable());
-	const char *s_converted = conv->Convert(name.c_str());
-	name = s_converted;
-	delete (conv);
-
-	name = convertEntities(name);
-
-	INF("resolves to " << name.c_str());
-	result.name = name;
-	result.successful = true;
 	return result;
 }
 
